bigq FractionsFeed this function a collection of numerator and denominator values;
get a vector of bigq fractions suitable for use as a FRACTRAN program.
fracMake(n, d = NULL)Vector of bigq fractions.
Vector of integers to be used as numerators, or a Nx2 array of integers
where each row contains a num, denom pair. If this is an arry, the input
d is ignored.
Vector of integers to be used as denominators. Ignored if n is an array
Carl Witthoft <carl@witthoft.com>